# resultsdatabase.py
# Copyright 2008 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Results database using Berkeley DB database via bsddb3.
"""

import os

# bsddb removed from Python 3.n
try:
    from bsddb3.db import (
        DB_BTREE,
        DB_HASH,
        DB_RECNO,
        DB_DUPSORT,
        DB_CREATE,
        DB_RECOVER,
        DB_INIT_MPOOL,
        DB_INIT_LOCK,
        DB_INIT_LOG,
        DB_INIT_TXN,
        DB_PRIVATE,
        )
except ImportError:
    from bsddb.db import (
        DB_BTREE,
        DB_HASH,
        DB_RECNO,
        DB_DUPSORT,
        DB_CREATE,
        DB_RECOVER,
        DB_INIT_MPOOL,
        DB_INIT_LOCK,
        DB_INIT_LOG,
        DB_INIT_TXN,
        DB_PRIVATE,
        )

from solentware_base.dbapi import DBapi

from solentware_misc.workarounds import dialogues

from ..core.filespec import FileSpec
from .. import ERROR_LOG


class ResultsDatabase(DBapi):
    """Methods and data structures to create, open, and close database."""

    _datasourceset_modulename = 'solentware_grid.core.datasourceset'
    _knownnames_modulename = 'chessresults.db.knownnames'

    def __init__(self, DBfile, **kargs):

        dbnames = FileSpec(**kargs)

        environment = {
            'flags': (DB_CREATE |
                      DB_RECOVER |
                      DB_INIT_MPOOL |
                      DB_INIT_LOCK |
                      DB_INIT_LOG |
                      DB_INIT_TXN |
                      DB_PRIVATE)
            }

        super(ResultsDatabase, self).__init__(
            dbnames,
            DBfile,
            environment)

    def delete_database(self):
        """Close and delete the open results database."""
        df = self.get_database_folder()
        files = [os.path.join(df, f) for f in self.get_database_filenames()]
        folders = [df]
        files.append(os.path.join(df, ERROR_LOG))
        # If temporary backups are used this will be list of files
        '''for extn in ('grd', 'zip'):
            files.append(
                os.path.join(
                    self.get_database_folder(),
                    '.'.join(
                        (self.get_database_instance(
                            GAME_FIELD_DEF,
                            GAME_FIELD_DEF).get_database_file(),
                    extn))))'''
        self.close_database()
        for f in files:
            if os.path.isfile(f):
                try:
                    os.remove(f)
                except:
                    pass
        done = True
        for f in folders:
            if os.path.isdir(f):
                try:
                    os.rmdir(f)
                except:
                    done = False
        if not done:
            dialogues.showinfo(
                title='Delete',
                message=''.join(
                    ('There is at least one file or folder in\n\n',
                     self.get_database_folder(),
                     '\n\nwhich may not be part of the database.  These items ',
                     'have not been deleted by Results.',
                     ))
                )
        return True
