# resultsdatabase.py
# Copyright 2011 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Results database using Sqlite3 database via sqlite3.
"""

import os

from solentware_base.sqlite3api import Sqlite3api

from ..core.filespec import FileSpec
from .. import ERROR_LOG


class ResultsDatabase(Sqlite3api):
    """Methods and data structures to create, open, and close database."""

    _datasourceset_modulename = 'solentware_grid.core.datasourceset'
    _knownnames_modulename = 'chessresults.sqlite.knownnames'

    def __init__(self, sqlite3file, **kargs):

        names = FileSpec(**kargs)

        super(ResultsDatabase, self).__init__(
            names,
            sqlite3file,
            **kargs)

    def delete_database(self):
        """Close and delete the open results database."""
        files = []
        folders = []
        files.append(self.get_database_filename())
        sqfolder = self.get_database_folder()
        folders.append(sqfolder)
        files.append(os.path.join(sqfolder, ERROR_LOG))
        # If temporary backups are used this will be list of files
        '''for extn in ('grd', 'zip'):
            files.append(
                os.path.join(
                    self.get_database_folder(),
                    '.'.join(
                        (self.get_database_instance(
                            GAME_FIELD_DEF,
                            GAME_FIELD_DEF).get_database_file(),
                    extn))))'''
        self.close_database()
        for f in files:
            if os.path.isfile(f):
                try:
                    os.remove(f)
                except:
                    pass
        done = True
        for f in folders:
            if os.path.isdir(f):
                try:
                    os.rmdir(f)
                except:
                    done = False
        if not done:
            dialogues.showinfo(
                title='Delete',
                message=''.join(
                    ('There is at least one file or folder in\n\n',
                     sqfolder,
                     '\n\nwhich may not be part of the database.  These items ',
                     'have not been deleted by Results.',
                     ))
                )
        return True
